@@ -54,6 +54,7 @@ class ConfigWorkRequirement:
     bash_script: Optional[str] = None
     capture_taskoutput: bool = True
     completed_task_ttl: Optional[float] = None  # In minutes
+    csv_files: Optional[List[str]] = None
     docker_env: Optional[Dict] = None
     docker_password: Optional[str] = None
     docker_username: Optional[str] = None
@@ -76,7 +77,7 @@ class ConfigWorkRequirement:
     ram: Optional[List[float]] = None
     regions: Optional[List[str]] = None
     task_count: int = 1
-    task_type: str = "bash"
+    task_type: str = Optional[str]
     tasks_data_file: Optional[str] = None
     tasks_per_worker: Optional[int] = None
     vcpus: Optional[List[float]] = None
@@ -95,14 +96,19 @@ class ConfigWorkerPool:
     auto_shutdown: bool = True
     auto_shutdown_delay: float = 10
     compute_requirement_batch_size: int = CR_BATCH_SIZE
-    initial_nodes: int = 0
+    images_id: Optional[str] = (None,)
+    instance_tags: Optional[Dict] = None
+    maintainInstanceCount: bool = False  # Only for yd-instantiate
     max_nodes: int = 0
     min_nodes: int = 0
     name: Optional[str] = None
     node_boot_time_limit: float = 10
+    target_instance_count: int = 0
     template_id: Optional[str] = None
+    user_data: Optional[str] = None
     worker_pool_data_file: Optional[str] = None
     worker_tag: Optional[str] = None
+    workers_per_vcpu: Optional[int] = None
     workers_per_node: int = 1
 
 
@@ -128,6 +134,10 @@ except FileNotFoundError as e:
         print_error(e)
         exit(1)
     # No config file, so create a stub config dictionary
+    print_log(
+        "No configuration file; expecting configuration data on command line "
+        "or in environment variables"
+    )
     CONFIG_TOML = {COMMON_SECTION: {}}
     CONFIG_FILE_DIR = os.getcwd()
 
@@ -174,6 +184,11 @@ def load_config_common() -> ConfigCommon:
                     f"for '{key_name}'"
                 )
 
+        DEFAULT_URL = "https://portal.yellowdog.co/api"
+        url = substitute_mustache_str(common_section.get(URL, DEFAULT_URL))
+        if url != DEFAULT_URL:
+            print_log(f"Using the YellowDog API at: {url}")
+
         return ConfigCommon(
             # Required
             key=substitute_mustache_str(common_section[KEY]),
@@ -181,9 +196,7 @@ def load_config_common() -> ConfigCommon:
             namespace=substitute_mustache_str(common_section[NAMESPACE]),
             name_tag=substitute_mustache_str(common_section[NAME_TAG]),
             # Optional
-            url=substitute_mustache_str(
-                common_section.get(URL, "https://portal.yellowdog.co/api")
-            ),
+            url=url,
         )
 
     except KeyError as e:
@@ -237,17 +250,20 @@ def load_config_work_requirement() -> Optional[ConfigWorkRequirement]:
         executable = substitute_mustache_str(executable)
 
         task_type = (
-            check_str(wr_section.get(TASK_TYPE, wr_section.get(TASK_TYPE, "bash")))
+            wr_section.get(TASK_TYPE, wr_section.get(TASK_TYPE, None))
             if ARGS_PARSER.task_type is None
             else ARGS_PARSER.task_type
         )
-        task_type = substitute_mustache_str(task_type)
+        if task_type is not None:
+            check_str(task_type)
+            task_type = substitute_mustache_str(task_type)
 
         return ConfigWorkRequirement(
             args=wr_section.get(ARGS, []),
             bash_script=wr_section.get(BASH_SCRIPT, None),  # Deprecated
             capture_taskoutput=wr_section.get(CAPTURE_TASKOUTPUT, True),
             completed_task_ttl=wr_section.get(COMPLETED_TASK_TTL, None),
+            csv_files=wr_section.get(CSV_FILES, None),
             docker_env=wr_section.get(DOCKER_ENV, None),
             docker_password=wr_section.get(DOCKER_PASSWORD, None),
             docker_username=wr_section.get(DOCKER_USERNAME, None),
@@ -312,18 +328,23 @@ def load_config_worker_pool() -> Optional[ConfigWorkerPool]:
             compute_requirement_batch_size=wp_section.get(
                 COMPUTE_REQUIREMENT_BATCH_SIZE, CR_BATCH_SIZE
             ),
-            initial_nodes=wp_section.get(INITIAL_NODES, 1),
+            images_id=wp_section.get(IMAGES_ID, None),
+            instance_tags=wp_section.get(INSTANCE_TAGS, None),
+            maintainInstanceCount=wp_section.get(MAINTAIN_INSTANCE_COUNT, False),
             max_nodes=wp_section.get(
-                MAX_NODES, max(1, wp_section.get(INITIAL_NODES, 1))
+                MAX_NODES, max(1, wp_section.get(TARGET_INSTANCE_COUNT, 1))
             ),
             min_nodes=wp_section.get(MIN_NODES, 0),
             name=substitute_mustache_str(
                 wp_section.get(WP_NAME, None),
             ),
             node_boot_time_limit=wp_section.get(NODE_BOOT_TIME_LIMIT, 10),
+            target_instance_count=wp_section.get(TARGET_INSTANCE_COUNT, 1),
             template_id=wp_section.get(TEMPLATE_ID, None),
+            user_data=wp_section.get(USERDATA, None),
             worker_pool_data_file=worker_pool_data_file,
             worker_tag=worker_tag,
+            workers_per_vcpu=wp_section.get(WORKERS_PER_VCPU, None),
             workers_per_node=wp_section.get(WORKERS_PER_NODE, 1),
         )
 
