@@ -41,6 +41,11 @@ from yd_commands.config import (
     load_config_work_requirement,
 )
 from yd_commands.config_keys import *
+from yd_commands.csv_data import (
+    load_json_file_with_csv_task_expansion,
+    perform_csv_task_expansion,
+)
+from yd_commands.interactive import confirmed
 from yd_commands.mustache import (
     LAZY_SUBS_WRAPPER,
     TASK_COUNT_SUB,
@@ -94,10 +99,27 @@ def main():
         if ARGS_PARSER.work_req_file is None
         else ARGS_PARSER.work_req_file
     )
-    if wr_data_file is not None:
+    csv_files = (
+        CONFIG_WR.csv_files if ARGS_PARSER.csv_files is None else ARGS_PARSER.csv_files
+    )
+
+    if wr_data_file is None and csv_files is not None:
+        tasks_data = csv_expand_toml_tasks(csv_files[0])
+        submit_work_requirement(
+            directory_to_upload_from=CONFIG_FILE_DIR,
+            tasks_data=tasks_data,
+        )
+
+    elif wr_data_file is not None:
         print_log(f"Loading Work Requirement data from: '{wr_data_file}'")
         if wr_data_file.lower().endswith("json"):
-            tasks_data = load_json_file_with_mustache_substitutions(wr_data_file)
+            if csv_files is not None:
+                tasks_data = load_json_file_with_csv_task_expansion(
+                    json_file=wr_data_file,
+                    csv_files=csv_files,
+                )
+            else:
+                tasks_data = load_json_file_with_mustache_substitutions(wr_data_file)
         elif wr_data_file.lower().endswith("toml"):
             tasks_data = load_toml_file_with_mustache_substitutions(wr_data_file)
         elif wr_data_file.lower().endswith("jsonnet"):
@@ -112,8 +134,13 @@ def main():
             directory_to_upload_from=dirname(wr_data_file),
             tasks_data=tasks_data,
         )
+
     else:
-        task_count = CONFIG_WR.task_count
+        task_count = (
+            CONFIG_WR.task_count
+            if ARGS_PARSER.task_count is None
+            else ARGS_PARSER.task_count
+        )
         submit_work_requirement(
             directory_to_upload_from=CONFIG_FILE_DIR, task_count=task_count
         )
@@ -512,7 +539,7 @@ def add_tasks_to_task_group(
                         input_folder_name=INPUT_FOLDER_NAME,
                         flatten_upload_paths=flatten_upload_paths,
                     ),
-                    verification=TaskInputVerification.VERIFY_WAIT,
+                    verification=TaskInputVerification.VERIFY_AT_START,
                 )
                 for file in input_files_list
             ]
@@ -831,7 +858,7 @@ def create_task(
                 input_folder_name=INPUT_FOLDER_NAME,
                 flatten_upload_paths=flatten_upload_paths,
             ),
-            verification=TaskInputVerification.VERIFY_WAIT,
+            verification=TaskInputVerification.VERIFY_AT_START,
         )
         # Avoid duplicate TaskInputs
         if task_input.objectNamePattern not in [x.objectNamePattern for x in inputs]:
@@ -972,6 +999,25 @@ def submit_json_raw(wr_file: str):
                 {input["objectNamePattern"] for input in task.get("inputs", [])}
             )
 
+        # Warn about required files & pause to allow upload
+        if len(input_files) != 0:
+            print_log(
+                "The following files may be required ('VERIFY_AT_START') "
+                "before Tasks are submitted, or the Tasks will fail."
+            )
+            print_log(
+                "You now have an opportunity to upload required files "
+                "before proceeding:\n"
+            )
+            print_numbered_strings(sorted(list(input_files)))
+            if not confirmed(
+                "Now proceed with Task submission (Y/y), or "
+                "Cancel Work Requirement (N)?"
+            ):
+                print_log(f"Cancelling Work Requirement '{wr_name}'")
+                CLIENT.work_client.cancel_work_requirement_by_id(wr_id)
+                return
+
         # Submit Tasks in batches
         batches = ceil(len(task_list) / TASK_BATCH_SIZE)
         for index in range(batches):
@@ -998,18 +1044,44 @@ def submit_json_raw(wr_file: str):
                 )
             else:
                 print_error(f"Failed to add Task(s) to Task Group '{task_group_name}'")
-                print_log(f"Cancelling Work Requirement '{wr_name}' [{wr_id}]")
+                print_log(f"Cancelling Work Requirement '{wr_name}'")
                 CLIENT.work_client.cancel_work_requirement_by_id(wr_id)
                 raise Exception(f"{response.text}")
 
-    if len(input_files) != 0:
-        print_log("Note: Files required by Tasks will not be uploaded automatically:\n")
-        print_numbered_strings(sorted(list(input_files)))
-
     if ARGS_PARSER.follow:
         follow_progress(CLIENT.work_client.get_work_requirement_by_id(wr_id))
 
 
+def csv_expand_toml_tasks(csv_file: str) -> Dict:
+    """
+    When there's a CSV file specified, but no JSON file, create the expanded
+    list of Tasks using the CSV data.
+    """
+    wr_data = {TASK_GROUPS: [{TASKS: [{}]}]}
+    task_proto = wr_data[TASK_GROUPS][0][TASKS][0]
+    for config_value, config_name in [
+        (CONFIG_WR.args, ARGS),
+        (CONFIG_WR.bash_script, BASH_SCRIPT),
+        (CONFIG_WR.capture_taskoutput, CAPTURE_TASKOUTPUT),
+        (CONFIG_WR.docker_env, DOCKER_ENV),
+        (CONFIG_WR.docker_password, DOCKER_PASSWORD),
+        (CONFIG_WR.docker_username, DOCKER_USERNAME),
+        (CONFIG_WR.env, ENV),
+        (CONFIG_WR.executable, EXECUTABLE),
+        (CONFIG_WR.flatten_input_paths, FLATTEN_PATHS),
+        (CONFIG_WR.input_files, INPUT_FILES),
+        (CONFIG_WR.wr_name, NAME),
+        (CONFIG_WR.output_files, OUTPUT_FILES),
+        (CONFIG_WR.task_type, TASK_TYPE),
+        (CONFIG_WR.verify_at_start, VERIFY_AT_START),
+        (CONFIG_WR.verify_wait, VERIFY_WAIT),
+    ]:
+        if config_value is not None:
+            task_proto[config_name] = config_value
+
+    return perform_csv_task_expansion(wr_data, [csv_file])
+
+
 # Standalone entry point
 if __name__ == "__main__":
     main()
